@@ -90,6 +90,10 @@ class Connector:
     on_sprite_out: Union[Callable[[SpriteOutMsg], None], Callable[[SpriteOutMsg, Connector], None]] = noop
     on_sprite_collision: Union[Callable[[SpriteCollisionMsg], None],
                                Callable[[SpriteCollisionMsg, Connector], None]] = noop
+    on_overlap_in: Union[Callable[[SpriteCollisionMsg], None],
+                         Callable[[SpriteCollisionMsg, Connector], None]] = noop
+    on_overlap_out: Union[Callable[[SpriteCollisionMsg], None],
+                          Callable[[SpriteCollisionMsg, Connector], None]] = noop
     on_border_overlap: Union[Callable[[BorderOverlapMsg], None], Callable[[BorderOverlapMsg, Connector], None]] = noop
     on_sprite_clicked: Union[Callable[[SpriteClickedMsg], None], Callable[[SpriteClickedMsg, Connector], None]] = noop
 
@@ -126,6 +130,25 @@ class Connector:
     def sprites(self) -> List[Sprite]:
         return self.__sprites
 
+    def get_sprite(self, id: str = None) -> Union[Sprite, None]:
+        '''returns the sprite with the given id
+
+        if no id is provided, the first sprite is returned
+
+        if the sprite is not found, None is returned
+        '''
+        if len(self.__sprites) == 0:
+            return None
+        if id is None:
+            return self.__sprites[0]
+        return first(lambda s: s.id == id, self.__sprites)
+
+    get_circle = get_sprite
+    get_ellipse = get_sprite
+    get_square = get_sprite
+    get_rectangle = get_sprite
+    get_object = get_sprite
+
     def __init__(self, server_url: str, device_id: str):
         device_id = device_id.strip()
         self.__server_url = server_url
@@ -622,6 +645,7 @@ class Connector:
                              shift_y: Optional[Number] = None,
                              color: Optional[Union[Colors, str]] = None,
                              images: Optional[Union[Path, str]] = None,
+                             image: Optional[str] = None,
                              **delivery_opts):
         '''
         Optional
@@ -671,11 +695,11 @@ class Connector:
 
             if not images.is_dir():
                 raise f'Image path {images} not found'
-            for image in images.iterdir():
-                if image.suffix in ['.jpg', '.jpeg', '.png', '.svg']:
-                    raw = image.read_bytes()
-                    name = image.stem
-                    file_type = image.suffix
+            for img in images.iterdir():
+                if img.suffix in ['.jpg', '.jpeg', '.png', '.svg']:
+                    raw = img.read_bytes()
+                    name = img.stem
+                    file_type = img.suffix
                     raw_images.append({'name': name, 'image': raw, 'type': file_type[1:]})
 
         playground_config = without_none({
@@ -684,6 +708,7 @@ class Connector:
                 'shift_x': shift_x if shift_x is not None else 0,
                 'shift_y': shift_y if shift_y is not None else 0,
                 'color': color,
+                'image': image,
                 'images': raw_images
             })
         self.__playground_config = playground_config
@@ -721,7 +746,8 @@ class Connector:
                 time_span: Optional[Number] = None,
                 width: Optional[Number] = None,
                 rotate: Optional[Number] = None,
-                **delivery_opts):
+                z_index: Optional[int] = None,
+                **rest) -> str:
             '''
             Optional
             --------
@@ -796,8 +822,9 @@ class Connector:
                 width = radius * 2
                 height = radius * 2
 
+            next_id = id if id is not None else f'sprite{randint(10000, 99999)}'
             s = {
-                'id': id if id is not None else f'sprite{randint(10000, 99999)}',
+                'id': next_id,
                 'clickable': clickable,
                 'collision_detection': collision_detection,
                 'color': color,
@@ -817,9 +844,11 @@ class Connector:
                 'image': image,
                 'rotate': rotate,
                 'time_span': time_span,
+                'z_index': z_index,
                 'width': width
             }
             sprites.append(without_none(s))
+            return next_id
 
         try:
             yield sprite
@@ -867,6 +896,7 @@ class Connector:
             image: Optional[str] = None,
             time_span: Optional[Number] = None,
             rotate: Optional[Number] = None,
+            z_index: Optional[int] = None,
             **delivery_opts) -> str:
         '''
         Optional
@@ -944,6 +974,7 @@ class Connector:
             border_color=border_color,
             font_color=font_color,
             font_size=font_size,
+            z_index=z_index,
             **delivery_opts
         )
 
@@ -971,6 +1002,7 @@ class Connector:
             image: Optional[str] = None,
             time_span: Optional[Number] = None,
             rotate: Optional[Number] = None,
+            z_index: Optional[int] = None,
             **delivery_opts) -> str:
         '''
         Optional
@@ -1051,6 +1083,7 @@ class Connector:
             border_color=border_color,
             font_color=font_color,
             font_size=font_size,
+            z_index=z_index,
             **delivery_opts
         )
     update_ellips = add_ellipse
@@ -1076,6 +1109,7 @@ class Connector:
             image: Optional[str] = None,
             time_span: Optional[Number] = None,
             rotate: Optional[Number] = None,
+            z_index: Optional[int] = None,
             **delivery_opts) -> str:
         '''
         Optional
@@ -1153,6 +1187,7 @@ class Connector:
             border_color=border_color,
             font_color=font_color,
             font_size=font_size,
+            z_index=z_index,
             **delivery_opts
         )
 
@@ -1180,6 +1215,7 @@ class Connector:
             image: Optional[str] = None,
             time_span: Optional[Number] = None,
             rotate: Optional[Number] = None,
+            z_index: Optional[int] = None,
             **delivery_opts) -> str:
         '''
         Optional
@@ -1260,6 +1296,7 @@ class Connector:
             border_color=border_color,
             font_color=font_color,
             font_size=font_size,
+            z_index=z_index,
             **delivery_opts
         )
 
@@ -1286,6 +1323,7 @@ class Connector:
             image: Optional[str] = None,
             time_span: Optional[Number] = None,
             rotate: Optional[Number] = None,
+            z_index: Optional[int] = None,
             **delivery_opts) -> str:
         config = DictX({'width': 100, 'height': 100})
         config.update(without_none(self.__playground_config))
@@ -1316,6 +1354,7 @@ class Connector:
             border_color=border_color,
             font_color=font_color,
             font_size=font_size,
+            z_index=z_index,
             **delivery_opts
         )
 
@@ -1344,6 +1383,7 @@ class Connector:
             time_span: Optional[Number] = None,
             width: Optional[Number] = None,
             rotate: Optional[Number] = None,
+            z_index: Optional[int] = None,
             **delivery_opts) -> str:
         '''
         Optional
@@ -1404,6 +1444,9 @@ class Connector:
 
         time_span : Number
             the time a sprite lives
+
+        z_index : int
+            set a custom z_index for the div
         '''
         sprite = {
             'id': id if id is not None else f'sprite{randint(10000, 99999)}',
@@ -1426,7 +1469,8 @@ class Connector:
             'rotate': rotate,
             'image': image,
             'time_span': time_span,
-            'width': width
+            'width': width,
+            'z_index': z_index
         }
         sprite = without_none(sprite)
         to_update = first(lambda s: s['id'] == sprite['id'], self.__sprites)
@@ -1481,6 +1525,7 @@ class Connector:
             line_width: Optional[Number] = None,
             color: Optional[Union[Colors, str]] = None,
             id: Optional[str] = None,
+            z_index: Optional[int] = None,
             **delivery_opts) -> str:
         '''Adds a line to the playground
 
@@ -1521,6 +1566,7 @@ class Connector:
             'y2': y2,
             'line_width': line_width,
             'color': color,
+            'z_index': z_index,
             'id': id if id is not None else f'line{randint(10000, 99999)}'
         }
 
@@ -1550,6 +1596,7 @@ class Connector:
             y2: Optional[Number] = None,
             line_width: Optional[Number] = None,
             color: Optional[Union[Colors, str]] = None,
+            z_index: Optional[int] = None,
             **delivery_opts) -> str:
         '''Updates a line already added to the playground
 
@@ -1588,6 +1635,7 @@ class Connector:
             y2=y2,
             line_width=line_width,
             color=color,
+            z_index=z_index,
             **delivery_opts
         )
 
@@ -1602,7 +1650,8 @@ class Connector:
                 y2: Number = None,
                 line_width: Optional[Number] = None,
                 color: Optional[Union[Colors, str]] = None,
-                id: Optional[str] = None) -> str:
+                id: Optional[str] = None,
+                z_index: Optional[int] = None) -> str:
             '''Adds or updates a line to the playground
 
             Parameters
@@ -1642,6 +1691,7 @@ class Connector:
                 'y2': y2,
                 'line_width': line_width,
                 'color': color,
+                'z_index': z_index,
                 'id': id if id is not None else f'line{randint(10000, 99999)}'
             }
             lines.append(without_none(l))
@@ -2244,6 +2294,11 @@ class Connector:
             elif data['type'] == DataType.SPRITE_COLLISION:
                 data['sprites'] = list(map(lambda s: DictX(s), data['sprites']))
                 self.__callback('on_sprite_collision', data)
+                if data['overlap'] == 'in':
+                    self.__callback('on_overlap_in', data)
+                elif data['overlap'] == 'out':
+                    self.__callback('on_overlap_out', data)
+
             elif data['type'] == DataType.BORDER_OVERLAP:
                 self.__callback('on_border_overlap', data)
             elif data['type'] == DataType.SPRITE_CLICKED:
